@@ -1,6 +1,8 @@
 """
 Defines the `Result` dataclass, representing success or failure, output by parsers.
 """
+from __future__ import annotations
+
 from dataclasses import dataclass
 from functools import reduce
 from typing import Callable, Optional, Type, TypeVar
@@ -8,8 +10,8 @@ from typing import Callable, Optional, Type, TypeVar
 from pytypeclass import Monad, MonadPlus, Monoid
 from pytypeclass.nonempty_list import NonemptyList
 
-from dollar_lambda.error import ArgumentError, BinaryError, HelpError, ZeroError
-from dollar_lambda.sequence import Sequence
+from dollar_lambda.data_structures import Sequence
+from dollar_lambda.errors import ArgumentError, BinaryError, HelpError, ZeroError
 
 Monoid_co = TypeVar("Monoid_co", covariant=True, bound=Monoid)
 Monoid1 = TypeVar("Monoid1", bound=Monoid)
@@ -42,7 +44,7 @@ class Result(MonadPlus[A_co]):
         self: "Result[Sequence[A]]", other: "Result[Sequence[B]]"
     ) -> "Result[Sequence[A | B]]":
         """
-        Sequence cs >> ds for each (cs, ds) in self.get * other.get.
+        Sequence ``cs >> ds`` for each ``(cs, ds)`` in ``self.get * other.get``.
         Short circuit at Exceptions.
         """
 
